@@ -39,5 +39,9 @@ class FileService:
 
     @staticmethod
     def delete_file(file_name: str) -> None:
-        """Delete the given file from the filesystem."""
+        """
+        Delete the given file from the filesystem.
+
+        :param file_name: File to delete.
+        """
         os.remove(file_name)
