@@ -112,6 +112,7 @@ class Buildvariant(BaseModel):
 class SetupReproEnvConfig(BaseModel):
     """Class represents setup repro env config."""
 
+    default_binary_task: str
     evergreen_tasks: List[Tasks]
     evergreen_buildvariants: List[Buildvariant]
 
@@ -133,8 +134,13 @@ class SetupReproEnvConfig(BaseModel):
                 )
             ],
             evergreen_buildvariants=[],
+            default_binary_task="",
         )
 
+    def get_default_binary_task(self) -> str:
+        """Get the name of the task that uploads the binaries."""
+        return self.default_binary_task
+
     def find_matching_build_variant(
         self, target: DownloadTarget, target_version: str
     ) -> Optional[str]:
